@@ -17,3 +17,7 @@ setGeneric("continue",function(object,...)standardGeneric("continue"))
 setGeneric("pred.mean",function(object,...)standardGeneric("pred.mean"))
 setGeneric("pred.var",function(object,...)standardGeneric("pred.var"))
 setGeneric("filter.mean",function(object,...)standardGeneric("filter.mean"))
+
+if (!exists("paste0",where="package:base")) {
+  paste0 <- function(...) paste(...,sep="")
+}
