@@ -27,16 +27,13 @@ static double logit (double x) {
 #define GAMMA       (p[parindex[0]]) // recovery rate
 #define MU          (p[parindex[1]]) // baseline birth and death rate
 #define IOTA        (p[parindex[2]]) // import rate
-#define LOGBETA     (p[parindex[3]]) // transmission rate
+#define BETA       (&p[parindex[3]]) // transmission rates
 #define BETA_SD     (p[parindex[4]]) // environmental stochasticity SD in transmission rate
 #define POPSIZE     (p[parindex[5]]) // population size
 #define RHO         (p[parindex[6]]) // reporting probability
-#define NBASIS      (p[parindex[7]]) // number of periodic B-spline basis functions
-#define DEGREE      (p[parindex[8]]) // degree of periodic B-spline basis functions
-#define PERIOD      (p[parindex[9]]) // period of B-spline basis functions
-#define S0         (p[parindex[10]]) // initial fraction of S
-#define I0         (p[parindex[11]]) // initial fraction of I
-#define R0         (p[parindex[12]]) // initial fraction of R
+#define S0          (p[parindex[7]]) // initial fraction of S
+#define I0          (p[parindex[8]]) // initial fraction of I
+#define R0          (p[parindex[9]]) // initial fraction of R
 
 #define SUSC      (x[stateindex[0]]) // number of susceptibles
 #define INFD      (x[stateindex[1]]) // number of infectives
@@ -44,36 +41,44 @@ static double logit (double x) {
 #define CASE      (x[stateindex[3]]) // number of cases (accumulated per reporting period)
 #define W         (x[stateindex[4]]) // integrated white noise
 
-#define DSDT    (f[stateindex[0]])
-#define DIDT    (f[stateindex[1]])
-#define DRDT    (f[stateindex[2]])
-#define DCDT    (f[stateindex[3]])
-#define DWDT    (f[stateindex[4]])
+#define DSDT      (f[stateindex[0]])
+#define DIDT      (f[stateindex[1]])
+#define DRDT      (f[stateindex[2]])
+#define DCDT      (f[stateindex[3]])
+#define DWDT      (f[stateindex[4]])
 
-#define REPORTS   (y[obsindex[0]])
+#define REPORTS     (y[obsindex[0]])
 
 void _sir_par_untrans (double *pt, double *p, int *parindex) 
 {
+  int nbasis = *(get_pomp_userdata_int("nbasis"));
+  int k;
   pt[parindex[0]] = log(GAMMA);
   pt[parindex[1]] = log(MU);
   pt[parindex[2]] = log(IOTA);
+  for (k = 0; k < nbasis; k++)
+    pt[parindex[3]+k] = log(BETA[k]);
   pt[parindex[4]] = log(BETA_SD);
   pt[parindex[6]] = logit(RHO);
-  pt[parindex[10]] = log(S0);
-  pt[parindex[11]] = log(I0);
-  pt[parindex[12]] = log(R0);
+  pt[parindex[7]] = log(S0);
+  pt[parindex[8]] = log(I0);
+  pt[parindex[9]] = log(R0);
 }
  
 void _sir_par_trans (double *pt, double *p, int *parindex) 
 {
+  int nbasis = *(get_pomp_userdata_int("nbasis"));
+  int k;
   pt[parindex[0]] = exp(GAMMA);
   pt[parindex[1]] = exp(MU);
   pt[parindex[2]] = exp(IOTA);
+  for (k = 0; k < nbasis; k++)
+    pt[parindex[3]+k] = exp(BETA[k]);
   pt[parindex[4]] = exp(BETA_SD);
   pt[parindex[6]] = expit(RHO);
-  pt[parindex[10]] = exp(S0);
-  pt[parindex[11]] = exp(I0);
-  pt[parindex[12]] = exp(R0);
+  pt[parindex[7]] = exp(S0);
+  pt[parindex[8]] = exp(I0);
+  pt[parindex[9]] = exp(R0);
 }
 
 void _sir_binom_dmeasure (double *lik, double *y, double *x, double *p, int give_log,
@@ -116,13 +121,16 @@ void _sir_euler_simulator (double *x, const double *p,
   double trans[nrate];		// transition numbers
   double beta;
   double dW;
-  int nseas = (int) NBASIS;	// number of seasonal basis functions
-  int deg = (int) DEGREE;	// degree of seasonal basis functions
-  double seasonality[nseas];
+  int nbasis = *(get_pomp_userdata_int("nbasis"));
+  int deg = *(get_pomp_userdata_int("degree"));
+  double period = *(get_pomp_userdata_double("period"));
+  double seasonality[nbasis];
+  int k;
 
-  if (nseas <= 0) return;
-  periodic_bspline_basis_eval(t,PERIOD,deg,nseas,&seasonality[0]);
-  beta = exp(dot_product(nseas,&seasonality[0],&LOGBETA));
+  if (nbasis <= 0) return;
+  periodic_bspline_basis_eval(t,period,deg,nbasis,&seasonality[0]);
+  for (k = 0, beta = 0; k < nbasis; k++)
+    beta += seasonality[k]*BETA[k];
 
   //  test to make sure the parameters and state variable values are sane
   if (!(R_FINITE(beta)) || 
@@ -171,13 +179,16 @@ void _sir_ODE (double *f, double *x, const double *p,
   double rate[nrate];		// transition rates
   double term[nrate];		// terms in the equations
   double beta;
-  int nseas = (int) NBASIS;	// number of seasonal basis functions
-  int deg = (int) DEGREE;	// degree of seasonal basis functions
-  double seasonality[nseas];
-  
-  if (nseas <= 0) return;
-  periodic_bspline_basis_eval(t,PERIOD,deg,nseas,&seasonality[0]);
-  beta = exp(dot_product(nseas,&seasonality[0],&LOGBETA));
+  int nbasis = *(get_pomp_userdata_int("nbasis"));
+  int deg = *(get_pomp_userdata_int("degree"));
+  double period = *(get_pomp_userdata_double("period"));
+  double seasonality[nbasis];
+  int k;
+
+  if (nbasis <= 0) return;
+  periodic_bspline_basis_eval(t,period,deg,nbasis,&seasonality[0]);
+  for (k = 0, beta = 0; k < nbasis; k++)
+    beta += seasonality[k]*BETA[k];
 
   // compute the transition rates
   rate[0] = MU*POPSIZE;		// birth into susceptible class
@@ -221,9 +232,11 @@ double _sir_rates (int j, double t, double *x, double *p,
 		   int ncovar, double *covar) {
   double beta;
   double rate = 0.0;
-  int nseas = (int) NBASIS;	// number of seasonal basis functions
-  int deg = (int) DEGREE;	// degree of seasonal basis functions
-  double seasonality[nseas];
+  int nbasis = *(get_pomp_userdata_int("nbasis"));
+  int deg = *(get_pomp_userdata_int("degree"));
+  double period = *(get_pomp_userdata_double("period"));
+  double seasonality[nbasis];
+  int k;
 
   switch (j) {
   case 1: 			// birth
@@ -233,8 +246,9 @@ double _sir_rates (int j, double t, double *x, double *p,
     rate = MU*SUSC;
     break;
   case 3:			// infection
-    periodic_bspline_basis_eval(t,PERIOD,deg,nseas,&seasonality[0]);
-    beta = exp(dot_product(nseas,&seasonality[0],&LOGBETA));
+    periodic_bspline_basis_eval(t,period,deg,nbasis,&seasonality[0]);
+    for (k = 0, beta = 0; k < nbasis; k++)
+      beta += seasonality[k]*BETA[k];
     rate = (beta*INFD+IOTA)*SUSC/POPSIZE;
     break;
   case 4:			// infected death
@@ -252,4 +266,3 @@ double _sir_rates (int j, double t, double *x, double *p,
   }
   return rate;
 }
-
